using UnityEngine;
using UnityEngine.Rendering;

/// <summary>
/// 自定义渲染管线资产
/// </summary>
[CreateAssetMenu(menuName = "Rendering/Custom Render Pipeline")]
public class CustomRenderPipelineAsset : RenderPipelineAsset
{
    [SerializeField]
    bool useDynamicBatching = true, useGPUInstancing = true, useSRPBatcher = true;
    // 是否使用逐对象光源
    [SerializeField]
    bool useLightsPerObject = true;

    [SerializeField]
    ShadowSettings shadows = default;

    // 后效资产配置
    [SerializeField]
    PostFXSettings postFXSettings = default;

    public enum ColorLUTResolution { _16 = 16, _32 = 32, _64 = 64 }

    // LUT分辨率
    [SerializeField]
    ColorLUTResolution colorLUTResolution = ColorLUTResolution._32;

    // HDR设置
    [SerializeField]
    bool allowHDR = true;
    protected override RenderPipeline CreatePipeline()
    {
        return new CustomRenderPipeline(allowHDR, useDynamicBatching, useGPUInstancing, useSRPBatcher, useLightsPerObject, shadows, postFXSettings, (int)colorLUTResolution);
    }
}
